==> hp300_1.0.tar: hp300/examples/concepts/io_import2.ex <==
#! /usr/lib/veetest/veetest -d /usr/lib/veetest -r
(revision "A.00.00")
(date "Thu 11/Apr/1991")
(component 0 "Context"
 (name "Importing a Waveform Text File Example 2")
 (interface
 )
 (implementation
  (trigMode deg)
  (locked no)
  (component 0 "RepeatUntilBreak"
   (name "Until Break #1")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Continuous")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 12 298)
     (extent 136 64)
     (iconImage loop.icon)
    )
    (detail
     (origin 45 190)
     (extent 70 40)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 1 "Start"
   (name "Start")
   (interface
    (sequence out)
   )
   (implementation
   )
   (views
    (icon
     (origin 46 221)
     (extent 69 39)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 2 "FromFile"
   (name "From File #2")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "X")
     (lock constraints)
     (optional yes)
    )
    (output 2
     (type data)
     (name "Y")
     (lock constraints)
     (optional yes)
    )
    (output 3
     (type data)
     (name "EOF")
     (tag "EOF")
     (lock name constraints)
     (optional yes)
    )
   )
   (implementation
    (attr iopath file read "/usr/lib/veetest/examples/concepts/io_import2.dat"
     (readTerm "\n")
     (fs " ")
     (eol "\n")
     (multiField fullSyntax)
     (arrayFormat block)
    )
    (procedure
      READ TEXT x,y REAL COUNT:1
    )
   )
   (views
    (icon
     (origin 245 228)
     (extent 118 25)
    )
    (detail
     (origin 212 523)
     (extent 327 114)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 3 "Break"
   (name "Break")
   (interface
    (sequence in)
   )
   (implementation
   )
   (views
    (icon
     (origin 551 698)
     (extent 78 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 4 "Note"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 422 119)
     (extent 397 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 5 "XYPlot"
   (name "X vs Y Plot")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "XData")
     (lock constraints)
    )
    (input 2
     (type data)
     (name "YData1")
     (lock constraints)
    )
    (input 3
     (type control)
     (name "Auto Scale")
     (lock name constraints)
     (optional yes)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
    (component tracePin 2)
    (component graphMode rectangular)
   )
   (views
    (icon
     (iconImage display.icon)
    )
    (detail
     (origin 669 516)
     (extent 323 208)
     (displayMode scrollGraph)
     (graphType cartesian)
     (gridType grid)
     (scale 0
      (name "Y name")
      (domainName "X name")
      (color 0x909090)
      (show 1)
      (range 0 14 3 linear)
     )
     (domain 0 14 3 linear)
     (trace 0 onScale 0
      (name "YData1")
      (color 0xffdd00)
      (lineType 1)
      (pointType 0)
     )
    )
    (active detail)
   )
  )
  (component 6 "RepeatUntilBreak"
   (name "Until Break #2")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Continuous")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 12 428)
     (extent 136 64)
     (iconImage loop.icon)
    )
    (detail
     (origin 45 370)
     (extent 70 40)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 7 "ScrollingTextDisplay"
   (name "Logging AlphaNumeric")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 688 334)
     (extent 264 133)
     (bufferSize 256)
    )
    (active detail)
   )
  )
  (component 8 "FromFile"
   (name "From File #1")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "X")
     (requires
      (datatype Text)
     )
     (lock constraints)
     (optional yes)
    )
   )
   (implementation
    (attr iopath file read "/usr/lib/veetest/examples/concepts/io_import2.dat"
     (readTerm "\n")
     (fs " ")
     (eol "\n")
     (multiField fullSyntax)
     (arrayFormat block)
    )
    (procedure
      READ TEXT x TOKEN COUNT:1
    )
   )
   (views
    (icon
     (origin 85 388)
     (extent 118 25)
    )
    (detail
     (origin 236 340)
     (extent 328 100)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 9 "IfThenElse"
   (name "If A == B")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (lock name constraints)
    )
    (input 2
     (type data)
     (name "B")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Then")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Else")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr "A==B")
   )
   (views
    (icon
     (origin 635 238)
     (extent 110 25)
    )
    (detail
     (origin 676 448)
     (extent 78 104)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 10 "Break"
   (name "Break")
   (interface
    (sequence in)
   )
   (implementation
   )
   (views
    (icon
     (origin 801 258)
     (extent 78 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 11 "Context"
   (name "Press For")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (trigMode deg)
    (locked no)
    (component 0 "IfThenElse"
     (name "!= 0")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "A")
       (optional yes)
      )
      (output 1
       (type data)
       (name "Then")
       (lock name constraints)
      )
      (output 2
       (type data)
       (name "Else")
       (lock name constraints)
      )
     )
     (implementation
      (component isLocked no)
      (component expr "a!=0")
     )
     (views
      (icon
       (origin 345 350)
       (extent 46 25)
      )
      (detail
       (origin 209 308)
       (extent 73 64)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "Toggle"
     (name "Info About")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type control)
       (name "Reset")
       (lock name constraints)
       (optional yes)
      )
      (output 1
       (type data)
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "Info About")
       (values range 0 1)
       (datum 0)
      )
      (component autoTrigger on)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (datum 0)
      )
     )
     (views
      (icon
       (origin 181 343)
       (extent 114 39)
       (format button)
      )
      (detail
       (origin 320 203)
       (extent 42 54)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "Context"
     (name "Info About...")
     (interface
      (sequence in)
      (sequence out)
     )
     (implementation
      (trigMode deg)
      (locked no)
      (component 0 "Note"
       (name "Info About")
       (interface
       )
       (implementation
        (component text 32 9
         Overview:
         This model illustrates how to read a data file created by another software package.
         In this case, the data file contains a sampled waveform with a variable-length file
         header.  The position of the waveform data points is marked by a special text marker.
         
         Details:
         The data file contains an unknown amount of information followed by a token that 
         marks the beginning of the data section.  The data section consists of an unknown 
         number of XY pairs separated by whitespace.
         
         Here are the contents of a typical data file:
         
         <MARKER1>Some Text
         <MARKER2>1 2 3 4
         <DATA>
         1	1.1
         2	2.2
         3	3.3
         .	.
         .	.
         .	.
         
         This is how the model works:
         
         The subthread attached to "Until Break #1"  strips away tokens one at a time as it 
         searches for <DATA>.  The transaction in "From File #1" uses the TOKEN format to 
         automatically parse  the input into tokens.  By default, a token is any string of 
         non-whitespace characters delimited by whitespace.
         
         The subthread attached to "Until Break #2" reads the numeric data that follows until 
         it reaches the end of the file.
         
        )
       )
       (views
        (icon
         (origin 375 448)
         (extent 110 25)
        )
        (detail
         (origin 124 479)
         (extent 452 282)
         (editing enabled)
        )
        (active icon)
       )
      )
      (component 1 "Confirm"
       (name "DONE")
       (interface
        (sequence in)
        (sequence out)
        (output 1
         (type data)
         (name "Go")
         (lock name constraints)
        )
       )
       (implementation
       )
       (views
        (icon
         (origin 411 512)
         (extent 58 37)
        )
        (detail
         (origin 466 633)
         (extent 79 34)
        )
        (terminals on)
        (active icon)
       )
      )
      (configuration
      )
      (ShowOnExecPanel
       (origin 86 135)
       (extent 849 571)
       (panel
        (origin 48 164)
        (extent 845 533)
        (widget 1 icon
         (title off)
         (origin 447 649)
         (extent 58 37)
        )
        (widget 0 detail
         (title off)
         (origin 72 177)
         (extent 809 447)
         (editing disabled)
        )
       )
      )
     )
     (views
      (icon
       (origin 407 418)
       (extent 127 25)
      )
      (detail
       (origin 295 430)
       (extent 351 200)
       (configuration
       )
      )
      (active icon)
     )
    )
    (configuration
     (connect D1:1 D0:1)
     (connect D0:0 D1:1)
     (connect D0:1 D2:0)
    )
   )
   (views
    (icon
     (origin 435 388)
     (extent 110 25)
    )
    (panel
     (origin 11 122)
     (extent 319 77)
     (widget 1 icon
      (title off)
      (origin 113 135)
      (extent 114 39)
      (format button)
     )
    )
    (detail
     (origin 4 115)
     (extent 912 591)
     (configuration
      (connect D1:1 D0:1
       (Point 297 362)
       (Point 342 362)
      )
      (connect D0:0 D1:1
       (Point 368 377)
       (Point 368 400)
       (Point 160 400)
       (Point 160 362)
       (Point 178 362)
      )
      (connect D0:1 D2:0
       (Point 393 352)
       (Point 470 352)
       (Point 470 415)
      )
     )
    )
    (active panel)
    (active panel)
   )
  )
  (component 12 "LiteralConstant"
   (name "Text")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (lock name constraints)
    )
   )
   (implementation
    (component value Text
     (name "Text")
     (datum "<DATA>")
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Text
     (datum "")
    )
   )
   (views
    (icon
    )
    (detail
     (origin 460 244)
     (extent 120 32)
    )
    (active detail)
   )
  )
  (configuration
   (connect D1:0 D0:0)
   (connect D6:1 D2:0)
   (connect D2:3 D3:0)
   (connect D2:1 D5:1)
   (connect D2:2 D5:2)
   (connect D2:3 D5:3)
   (connect D0:0 D6:0)
   (connect D8:1 D7:1)
   (connect D0:1 D8:0)
   (connect D12:1 D9:1)
   (connect D8:1 D9:2)
   (connect D9:1 D10:0)
  )
 )
 (views
  (detail
   (origin 0 67)
   (extent 1046 651)
   (configuration
    (connect D1:0 D0:0
     (Point 80 262)
     (Point 80 295)
    )
    (connect D6:1 D2:0
     (Point 150 460)
     (Point 380 460)
     (Point 380 490)
    )
    (connect D2:3 D3:0
     (Point 581 620)
     (Point 600 620)
     (Point 600 660)
     (Point 590 660)
     (Point 590 695)
    )
    (connect D2:1 D5:1
     (Point 581 540)
     (Point 600 540)
     (Point 600 550)
     (Point 666 550)
    )
    (connect D2:2 D5:2
     (Point 581 580)
     (Point 610 580)
     (Point 610 620)
     (Point 666 620)
    )
    (connect D2:3 D5:3
     (Point 581 620)
     (Point 600 620)
     (Point 600 660)
     (Point 650 660)
     (Point 650 690)
     (Point 666 690)
    )
    (connect D0:0 D6:0
     (Point 80 364)
     (Point 80 425)
    )
    (connect D8:1 D7:1
     (Point 596 390)
     (Point 620 390)
     (Point 620 400)
     (Point 685 400)
    )
    (connect D0:1 D8:0
     (Point 150 330)
     (Point 170 330)
     (Point 170 290)
     (Point 400 290)
     (Point 400 307)
    )
    (connect D12:1 D9:1
     (Point 582 260)
     (Point 600 260)
     (Point 600 240)
     (Point 632 240)
    )
    (connect D8:1 D9:2
     (Point 596 390)
     (Point 620 390)
     (Point 620 260)
     (Point 632 260)
    )
    (connect D9:1 D10:0
     (Point 747 240)
     (Point 840 240)
     (Point 840 255)
    )
   )
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)

==> hp300_1.4.tar: hp300/examples/concepts/io_import2.ex <==
#! /usr/lib/veetest/veetest -r
(revision "A.00.00")
(date "Thu 16/May/1991")
(component 0 "Context"
 (name "Importing a Waveform Text File Example 2")
 (interface
 )
 (implementation
  (trigMode deg)
  (locked no)
  (component 0 "RepeatUntilBreak"
   (name "Until Break #1")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Continuous")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 12 298)
     (extent 136 64)
     (iconImage loop.icon)
    )
    (detail
     (origin 45 190)
     (extent 70 40)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 1 "Start"
   (name "Start")
   (interface
    (sequence out)
   )
   (implementation
   )
   (views
    (icon
     (origin 46 221)
     (extent 69 39)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 2 "FromFile"
   (name "From File #2")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "X")
     (lock constraints)
     (optional yes)
    )
    (output 2
     (type data)
     (name "Y")
     (lock constraints)
     (optional yes)
    )
    (output 3
     (type data)
     (name "EOF")
     (tag "EOF")
     (lock name constraints)
     (optional yes)
    )
   )
   (implementation
    (attr iopath file read "/usr/lib/veetest/examples/concepts/io_import2.dat"
     (readTerm "\n")
     (fs " ")
     (eol "\n")
     (multiField fullSyntax)
     (arrayFormat block)
    )
    (procedure
      READ TEXT x,y REAL COUNT:1
    )
   )
   (views
    (icon
     (origin 245 228)
     (extent 118 25)
    )
    (detail
     (origin 212 523)
     (extent 327 114)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 3 "Note"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 422 119)
     (extent 397 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 4 "RepeatUntilBreak"
   (name "Until Break #2")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Continuous")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 12 428)
     (extent 136 64)
     (iconImage loop.icon)
    )
    (detail
     (origin 45 370)
     (extent 70 40)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 5 "ScrollingTextDisplay"
   (name "Logging AlphaNumeric")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 688 334)
     (extent 264 133)
     (bufferSize 256)
    )
    (active detail)
   )
  )
  (component 6 "FromFile"
   (name "From File #1")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "X")
     (requires
      (datatype Text)
     )
     (lock constraints)
     (optional yes)
    )
   )
   (implementation
    (attr iopath file read "/usr/lib/veetest/examples/concepts/io_import2.dat"
     (readTerm "\n")
     (fs " ")
     (eol "\n")
     (multiField fullSyntax)
     (arrayFormat block)
    )
    (procedure
      READ TEXT x TOKEN COUNT:1
    )
   )
   (views
    (icon
     (origin 85 388)
     (extent 118 25)
    )
    (detail
     (origin 236 340)
     (extent 328 100)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 7 "IfThenElse"
   (name "If A == B")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (lock name constraints)
    )
    (input 2
     (type data)
     (name "B")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Then")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Else")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr "A==B")
   )
   (views
    (icon
     (origin 635 238)
     (extent 110 25)
    )
    (detail
     (origin 676 448)
     (extent 78 104)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 8 "Break"
   (name "Break")
   (interface
    (sequence in)
   )
   (implementation
   )
   (views
    (icon
     (origin 801 258)
     (extent 78 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 9 "Context"
   (name "Press For")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (trigMode deg)
    (locked no)
    (component 0 "IfThenElse"
     (name "!= 0")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "A")
       (optional yes)
      )
      (output 1
       (type data)
       (name "Then")
       (lock name constraints)
      )
      (output 2
       (type data)
       (name "Else")
       (lock name constraints)
      )
     )
     (implementation
      (component isLocked no)
      (component expr "a!=0")
     )
     (views
      (icon
       (origin 345 350)
       (extent 46 25)
      )
      (detail
       (origin 209 308)
       (extent 73 64)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "Toggle"
     (name "Info About")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type control)
       (name "Reset")
       (lock name constraints)
       (optional yes)
      )
      (output 1
       (type data)
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "Info About")
       (values range 0 1)
       (datum 0)
      )
      (component autoTrigger on)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (datum 0)
      )
     )
     (views
      (icon
       (origin 181 343)
       (extent 114 39)
       (format button)
      )
      (detail
       (origin 320 203)
       (extent 42 54)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "Context"
     (name "Info About...")
     (interface
      (sequence in)
      (sequence out)
     )
     (implementation
      (trigMode deg)
      (locked no)
      (component 0 "Note"
       (name "Info About")
       (interface
       )
       (implementation
        (component text 32 9
         Overview:
         This model illustrates how to read a data file created by another software package.
         In this case, the data file contains a sampled waveform with a variable-length file
         header.  The position of the waveform data points is marked by a special text marker.
         
         Details:
         The data file contains an unknown amount of information followed by a token that 
         marks the beginning of the data section.  The data section consists of an unknown 
         number of XY pairs separated by whitespace.
         
         Here are the contents of a typical data file:
         
         <MARKER1>Some Text
         <MARKER2>1 2 3 4
         <DATA>
         1	1.1
         2	2.2
         3	3.3
         .	.
         .	.
         .	.
         
         This is how the model works:
         
         The subthread attached to "Until Break #1"  strips away tokens one at a time as it 
         searches for <DATA>.  The transaction in "From File #1" uses the TOKEN format to 
         automatically parse  the input into tokens.  By default, a token is any string of 
         non-whitespace characters delimited by whitespace.
         
         The subthread attached to "Until Break #2" reads the numeric data that follows until 
         it reaches the end of the file.
         
        )
       )
       (views
        (icon
         (origin 375 448)
         (extent 110 25)
        )
        (detail
         (origin 124 479)
         (extent 452 282)
         (editing enabled)
        )
        (active icon)
       )
      )
      (component 1 "Confirm"
       (name "DONE")
       (interface
        (sequence in)
        (sequence out)
        (output 1
         (type data)
         (name "Go")
         (lock name constraints)
        )
       )
       (implementation
       )
       (views
        (icon
         (origin 411 512)
         (extent 58 37)
        )
        (detail
         (origin 466 633)
         (extent 79 34)
        )
        (terminals on)
        (active icon)
       )
      )
      (configuration
      )
      (ShowOnExecPanel
       (origin 86 135)
       (extent 849 571)
       (panel
        (origin 48 164)
        (extent 845 533)
        (widget 1 icon
         (title off)
         (origin 447 649)
         (extent 58 37)
        )
        (widget 0 detail
         (title off)
         (origin 72 177)
         (extent 809 447)
         (editing disabled)
        )
       )
      )
     )
     (views
      (icon
       (origin 407 418)
       (extent 127 25)
      )
      (detail
       (origin 295 430)
       (extent 351 200)
       (configuration
       )
      )
      (active icon)
     )
    )
    (configuration
     (connect D1:1 D0:1)
     (connect D0:0 D1:1)
     (connect D0:1 D2:0)
    )
   )
   (views
    (icon
     (origin 435 388)
     (extent 110 25)
    )
    (panel
     (origin 11 122)
     (extent 319 77)
     (widget 1 icon
      (title off)
      (origin 113 135)
      (extent 114 39)
      (format button)
     )
    )
    (detail
     (origin 4 115)
     (extent 912 591)
     (configuration
      (connect D1:1 D0:1
       (Point 297 362)
       (Point 342 362)
      )
      (connect D0:0 D1:1
       (Point 368 377)
       (Point 368 400)
       (Point 160 400)
       (Point 160 362)
       (Point 178 362)
      )
      (connect D0:1 D2:0
       (Point 393 352)
       (Point 470 352)
       (Point 470 415)
      )
     )
    )
    (active panel)
    (active panel)
   )
  )
  (component 10 "LiteralConstant"
   (name "Text")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (lock name constraints)
    )
   )
   (implementation
    (component value Text
     (name "Text")
     (datum "<DATA>")
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Text
     (datum "")
    )
   )
   (views
    (icon
    )
    (detail
     (origin 460 244)
     (extent 120 32)
    )
    (active detail)
   )
  )
  (component 11 "XYPlot"
   (name "X vs Y Plot")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "XData")
     (lock constraints)
    )
    (input 2
     (type data)
     (name "YData1")
     (lock constraints)
    )
    (input 3
     (type control)
     (name "Auto Scale")
     (lock name constraints)
     (optional yes)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
    (component tracePin 2)
    (component graphMode rectangular)
   )
   (views
    (icon
     (iconImage display.icon)
    )
    (detail
     (origin 669 506)
     (extent 323 208)
     (displayMode scrollGraph)
     (graphType cartesian)
     (gridType grid)
     (scale 0
      (name "Y name")
      (domainName "X name")
      (color 0x909090)
      (show 1)
      (range 0 14 3 linear)
     )
     (domain 0 14 3 linear)
     (trace 0 onScale 0
      (name "YData1")
      (color 0xffdd00)
      (lineType 1)
      (pointType 0)
     )
    )
    (active detail)
   )
  )
  (component 12 "Do"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Do")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 577 668)
     (extent 46 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 13 "Break"
   (name "Break")
   (interface
    (sequence in)
   )
   (implementation
   )
   (views
    (icon
     (origin 561 708)
     (extent 78 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (configuration
   (connect D1:0 D0:0)
   (connect D4:1 D2:0)
   (connect D0:0 D4:0)
   (connect D6:1 D5:1)
   (connect D0:1 D6:0)
   (connect D10:1 D7:1)
   (connect D6:1 D7:2)
   (connect D7:1 D8:0)
   (connect D2:1 D11:1)
   (connect D2:2 D11:2)
   (connect D12:1 D11:3)
   (connect D2:3 D12:0)
   (connect D12:0 D13:0)
  )
 )
 (views
  (detail
   (origin 0 67)
   (extent 1255 930)
   (configuration
    (connect D1:0 D0:0
     (Point 80 262)
     (Point 80 295)
    )
    (connect D4:1 D2:0
     (Point 150 460)
     (Point 380 460)
     (Point 380 490)
    )
    (connect D0:0 D4:0
     (Point 80 364)
     (Point 80 425)
    )
    (connect D6:1 D5:1
     (Point 596 390)
     (Point 620 390)
     (Point 620 400)
     (Point 685 400)
    )
    (connect D0:1 D6:0
     (Point 150 330)
     (Point 170 330)
     (Point 170 290)
     (Point 400 290)
     (Point 400 307)
    )
    (connect D10:1 D7:1
     (Point 582 260)
     (Point 600 260)
     (Point 600 240)
     (Point 632 240)
    )
    (connect D6:1 D7:2
     (Point 596 390)
     (Point 620 390)
     (Point 620 260)
     (Point 632 260)
    )
    (connect D7:1 D8:0
     (Point 747 240)
     (Point 840 240)
     (Point 840 255)
    )
    (connect D2:1 D11:1
     (Point 581 540)
     (Point 666 540)
    )
    (connect D2:2 D11:2
     (Point 581 580)
     (Point 600 580)
     (Point 600 610)
     (Point 666 610)
    )
    (connect D12:1 D11:3
     (Point 625 680)
     (Point 666 680)
    )
    (connect D2:3 D12:0
     (Point 581 620)
     (Point 600 620)
     (Point 600 665)
    )
    (connect D12:0 D13:0
     (Point 600 695)
     (Point 600 705)
    )
   )
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)
